{% extends "organizations_base.html" %}
{% load url from future %}

{% block content %}
<h1>organizations</h1>

<ul>
    {% for organization in organizations %}
    <li><a href="{{ organization.get_absolute_url }}">{{ organization }}</a></li>
    {% endfor %}
</ul>

<br>

<a href="{% url 'organization_add' %}">Add new organization</a>
<br>
{% endblock %}
